pub struct CodeGenerator<'e> { /* private fields */ }Expand description
Uses an inference engine to generate Rust source for a CapabilityRequest.
Implementations
Sourceimpl<'e> CodeGenerator<'e>
impl<'e> CodeGenerator<'e>
pub fn new(engine: &'e dyn InferenceEngine, soul: &'e Soul) -> Self
Sourcepub async fn generate(
&self,
req: &CapabilityRequest,
) -> Result<GeneratedTool, String>
pub async fn generate( &self, req: &CapabilityRequest, ) -> Result<GeneratedTool, String>
Generate Rust source code for req.
Returns Err if the model call fails or no code block is present in
the response. Static analysis violations do NOT cause an Err — they
are reported inside GeneratedTool.