Module static_analysis

Module static_analysis 

Structs

StaticAnalysisReport
StaticViolation

Functions

check
Scan source for forbidden patterns. Returns a report of all violations. An empty violations list means the source passed all checks.
has_tests
True if the source contains at least one #[test] function.
test_count
Count the number of #[test] occurrences in the source.