pub fn check(source: &str) -> StaticAnalysisReportExpand description
Scan source for forbidden patterns. Returns a report of all violations.
An empty violations list means the source passed all checks.
pub fn check(source: &str) -> StaticAnalysisReportScan source for forbidden patterns. Returns a report of all violations.
An empty violations list means the source passed all checks.