Module code_gen
split_
brain_
harness
1.0.0
Module code_
gen
Module Items
Structs
Functions
In crate split_
brain_
harness
split_brain_harness
Module
code_
gen
Structs

Code
Generator
Uses an inference engine to generate Rust source for a CapabilityRequest.
Generated
Tool
The result of one code generation pass.
Functions

build_
prompt
Build the generation prompt from a CapabilityRequest.
extract_
code_
block
Extract the content of the first
```rust ... ```
block in
response
. Returns
None
if no such block exists or the block is empty after trimming. Accepts both
rust
and
Rust
language tags and both LF and CRLF endings.
extract_
function_
name
Find the first
pub fn
or
fn
name in the source.